@@ -805,7 +805,7 @@ private:
   // GROUP data
   TQString firstName;
   TQString lastName;
-  Qt::Orientation splitterOrientation;
+  TQt::Orientation splitterOrientation;
   bool isGroup;
   bool isTabGroup;
 
@@ -942,7 +942,7 @@ public:
   void setSplitterOpaqueResize(bool b=true);
 
   /**
-   * Returns TRUE if opaque resizing is enabled, FALSE otherwise.
+   * Returns true if opaque resizing is enabled, false otherwise.
    */
   bool splitterOpaqueResize() const;
 
@@ -954,7 +954,7 @@ public:
   void setSplitterKeepSize(bool b=true);
 
   /**
-   * Returns TRUE if the KeepSize is enabled, FALSE otherwise.
+   * Returns true if the KeepSize is enabled, false otherwise.
    */
   bool splitterKeepSize() const;
 
@@ -967,7 +967,7 @@ public:
   void setSplitterHighResolution(bool b=true);
 
   /**
-   * Returns TRUE if the splitter uses the high resolution, FALSE otherwise.
+   * Returns true if the splitter uses the high resolution, false otherwise.
    */
   bool splitterHighResolution() const;
 
