@@ -25,7 +25,7 @@ class TQCheckBox;
 
 class ImageSettings : public KPrintDialogPage
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		ImageSettings( TQWidget * parent = 0, const char * name = 0 );
