@@ -85,7 +85,7 @@ DocumentWidget::DocumentWidget(TQWidget *parent, PageView *sv, DocumentPageCache
   setMouseTracking(true);
   setFocusPolicy(TQWidget::ClickFocus);
 
-  connect(&clearStatusBarTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(clearStatusBar()));
+  connect(&clearStatusBarTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(clearStatusBar()));
   setBackgroundMode(TQt::NoBackground);
 
   if (!busyIcon)
@@ -260,7 +260,7 @@ void DocumentWidget::paintEvent(TQPaintEvent *e)
     {
       // Request page pixmap.
       pixmapRequested = true;
-      TQTimer::singleShot(50, this, TQT_SLOT(delayedRequestPage()));
+      TQTimer::singleShot(50, this, TQ_SLOT(delayedRequestPage()));
     }
     return;
   }
@@ -367,7 +367,7 @@ void DocumentWidget::drawScrollGuide(int ycoord)
   //kdDebug() << "draw scroll guide for page " << pageNr << " at y = " << ycoord << endl;
   scrollGuide = ycoord;
   update(TQRect(1, scrollGuide, pageSize().width(), 1));
-  TQTimer::singleShot(1000, this, TQT_SLOT(clearScrollGuide()));
+  TQTimer::singleShot(1000, this, TQ_SLOT(clearScrollGuide()));
 }
 
 void DocumentWidget::clearScrollGuide()
@@ -450,7 +450,7 @@ void DocumentWidget::mousePressEvent ( TQMouseEvent * e )
   }
 
   // Check if the mouse is pressed on a regular hyperlink
-  if (e->button() == Qt::LeftButton) {
+  if (e->button() == TQt::LeftButton) {
     if (pageData->hyperLinkList.size() > 0)
       for(unsigned int i = 0; i < pageData->hyperLinkList.size(); i++) {
         if (pageData->hyperLinkList[i].box.contains(e->pos())) {
@@ -464,7 +464,7 @@ void DocumentWidget::mousePressEvent ( TQMouseEvent * e )
       setCursor(TQt::IbeamCursor);
   }
 
-  if (e->button() == Qt::RightButton || (!moveTool && e->button() == Qt::LeftButton))
+  if (e->button() == TQt::RightButton || (!moveTool && e->button() == TQt::LeftButton))
   {
     setCursor(TQt::IbeamCursor);
     // If Shift is not pressed clear the current selection,
@@ -486,7 +486,7 @@ void DocumentWidget::mouseReleaseEvent ( TQMouseEvent *e )
   // otherwise the mouse cursor in the centeringScrollview is wrong
   e->ignore();
 
-  if (e->button() == Qt::RightButton || (!moveTool && e->button() == Qt::LeftButton))
+  if (e->button() == TQt::RightButton || (!moveTool && e->button() == TQt::LeftButton))
   {
     // If the selectedRectangle is empty then there was only a single right click.
     if (firstSelectedPoint == e->pos())
@@ -589,7 +589,7 @@ void DocumentWidget::mouseMoveEvent ( TQMouseEvent * e )
     clearStatusBarTimer.start(200, true); // clear the statusbar after 200 msec.
 
   // Left mouse button pressed -> Text scroll function
-  if ((e->state() & Qt::LeftButton) != 0 && moveTool)
+  if ((e->state() & TQt::LeftButton) != 0 && moveTool)
   {
     // Pass the mouse event on to the owner of this widget ---under
     // normal circumstances that is the centeringScrollView which will
@@ -598,7 +598,7 @@ void DocumentWidget::mouseMoveEvent ( TQMouseEvent * e )
   }
 
   // Right mouse button pressed -> Text copy function
-  if ((e->state() & Qt::RightButton) != 0 || (!moveTool && (e->state() & Qt::LeftButton != 0)))
+  if ((e->state() & TQt::RightButton) != 0 || (!moveTool && (e->state() & TQt::LeftButton != 0)))
   {
     if (selectedRectangle.isEmpty()) {
       firstSelectedPoint = e->pos();
