@@ -28,7 +28,7 @@ class TQStringList;
 
 class KPdfPlugin: public KFilePlugin
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     KPdfPlugin( TQObject *parent, const char *name, const TQStringList& preferredItems );
